# History

## 0.2.1 - 2020-06-22

This release curates some of the dependencies and updates the example datasets
and documentation.

## 0.2.0 - 2019-11-26

Second Release:

* Improved CLI interface
* Improved Dataset support
* New Docker image
* Newer dependencies

This is the version used to generate the results explained in the third version of [
The Machine Learning Bazaar Paper](https://arxiv.org/abs/1905.08942v3)

## 0.1.0 - 2019-06-24

First Release.

This is a slightly cleaned up version of the software used to generate the results
explained in the first version of [The Machine Learning Bazaar Paper](
https://arxiv.org/abs/1905.08942v1)
